clear
local path="C:\Users\a0910846\Dropbox\County\FivaHalseReplication" /* INSERT DIRECTORY HERE */
cap mkdir "`path'\tables"
cap mkdir "`path'\temp"
cap mkdir "`path'\figures"
cap mkdir "`path'\gph"
cd `path'

/* REMARKS:
- STATA v.14 required for replication code to run
- List vote share replaced with ballot vote share in Figure A.2 and A.3
*/

/* packages that need to be installed for code to work */
*ssc install estout, replace
*ssc install latab, replace
*ssc install binscatter, replace
*ssc install listtab, replace
*net install rdrobust, from(http://www-personal.umich.edu/~cattaneo/software/rdrobust/stata-2014) replace


*******************************************************************************


*** TABLE 1: DESCRIPTIVE, OUTCOME VARIABLES ***

use dta\panel_mun_elperiod.dta, clear

latabstat sum sumCAP, stat(p50 p90 p99 n) columns(statistics) f(%9.1f) 
*(Cut and paste into manuscript - fix variable names)

*******************************************************************************


*** TABLE 2: SHARES IN EACH REPRESENTATION CATEGORY ***

use dta\panel_mun_elperiod.dta, clear

gen drepRight=max(drepRight1,drepRight2,drepRight3)

tab drepLeft drepRight, cell
*(Insert numbers in table)

*******************************************************************************


*** FIGURE 1: PROBABILITY OF RIGHTWING GOVERNOR ***

use dta\panel_mun_elperiod.dta, clear

gen GovRight=max(GovRight1,GovRight2,GovRight3)

cd gph
rdplot GovRight dist_coal_margin, c(0) p(3) binselect(qs) scalel(5) scaler(0.15) graph_options(graphregion(fcolor(white)) title("(A)", position(10)) legend(off) yscale(range(0 1)) ylabel(#5, angle(0)) xscale(range(-0.25 0.25)) xlabel(-0.2(0.1)0.2)))
graph save GovernorRight_full.gph, replace
rdplot GovRight dist_coal_margin if abs(dist_coal_margin)<=0.1, c(0) p(1) binselect(qs) scalel(8) scaler(0.27) graph_options(graphregion(fcolor(white)) title("(B)", position(10)) legend(off) yscale(range(0 1)) ylabel(#5, angle(0)) xscale(range(-0.1 0.1)) xlabel(-0.1(0.05)0.1)))
graph save GovernorRight_bw20.gph, replace
graph combine GovernorRight_full.gph GovernorRight_bw20.gph, ysize(2.5) graphregion(fcolor(white)) iscale(1.2)
graph export ..\Figures\Fig_1.pdf, replace

cd ..

*******************************************************************************


*** FIGURE 2: FUNDING TO LOCAL GOVERNMENTS, SPLIT BY REPRESENTATION ***

/* Run separate do-files to get p-values:
wildboot ITT bw50.do
wildboot ITT bw10.do */

use dta\panel_mun_elperiod.dta, clear

gen drepRight=max(drepRight1,drepRight2,drepRight3)
renpfix drep

rdplot sumCAP dist_coal_margin if Left==0&Right==0, c(0) p(3) numbinl(4) numbinr(16) graph_options(graphregion(color(white)) title("(A)", position(10)) legend(off) yscale(range(0 1500)) ylabel(#4, angle(0)) xscale(range(-0.25 0.25)) xlabel(-0.2(0.1)0.2)))
graph save gph\rdplot_sumCAP_full_Left0Right0.gph, replace
rdplot sumCAP dist_coal_margin if Left==0&Right==0&abs(dist_coal_margin)<=0.1, c(0) p(1) numbinl(8) numbinr(12) graph_options(graphregion(color(white)) title("(B)", position(10)) legend(off) yscale(range(0 1500)) ylabel(#4, angle(0)) xscale(range(-0.1 0.1)) xlabel(-0.1(0.05)0.1)))
graph save gph\rdplot_sumCAP_bw20_Left0Right0.gph, replace
rdplot sumCAP dist_coal_margin if Left==1&Right==0, c(0) p(3) numbinl(8) numbinr(12) graph_options(graphregion(color(white)) title("(A)", position(10)) legend(off) yscale(range(0 1500)) ylabel(#4, angle(0)) xscale(range(-0.25 0.25)) xlabel(-0.2(0.1)0.2)))
graph save gph\rdplot_sumCAP_full_Left1Right0.gph, replace
rdplot sumCAP dist_coal_margin if Left==1&Right==0&abs(dist_coal_margin)<=0.1, c(0) p(1) numbinl(10) numbinr(10) graph_options(graphregion(color(white)) title("(B)", position(10)) legend(off) yscale(range(0 1500)) ylabel(#4, angle(0)) xscale(range(-0.1 0.1)) xlabel(-0.1(0.05)0.1)))
graph save gph\rdplot_sumCAP_bw20_Left1Right0.gph, replace
rdplot sumCAP dist_coal_margin if Left==0&Right==1, c(0) p(3) numbinl(3) numbinr(17) graph_options(graphregion(color(white)) title("(A)", position(10)) legend(off) yscale(range(0 1500)) ylabel(#4, angle(0)) xscale(range(-0.25 0.25)) xlabel(-0.2(0.1)0.2)))
graph save gph\rdplot_sumCAP_full_Left0Right1.gph, replace
rdplot sumCAP dist_coal_margin if Left==0&Right==1&abs(dist_coal_margin)<=0.1, c(0) p(1) numbinl(6) numbinr(14) graph_options(graphregion(color(white)) title("(B)", position(10)) legend(off) yscale(range(0 1500)) ylabel(#4, angle(0)) xscale(range(-0.1 0.1)) xlabel(-0.1(0.05)0.1)))
graph save gph\rdplot_sumCAP_bw20_Left0Right1.gph, replace
rdplot sumCAP dist_coal_margin if Left==1&Right==1, c(0) p(3) numbinl(6) numbinr(14) graph_options(graphregion(color(white)) title("(A)", position(10)) legend(off) yscale(range(0 1500)) ylabel(#4, angle(0)) xscale(range(-0.25 0.25)) xlabel(-0.2(0.1)0.2)))
graph save gph\rdplot_sumCAP_full_Left1Right1.gph, replace
rdplot sumCAP dist_coal_margin if Left==1&Right==1&abs(dist_coal_margin)<=0.1, c(0) p(1) numbinl(8) numbinr(12) graph_options(graphregion(color(white)) title("(B)", position(10)) legend(off) yscale(range(0 1500)) ylabel(#4, angle(0)) xscale(range(-0.1 0.1)) xlabel(-0.1(0.05)0.1)))
graph save gph\rdplot_sumCAP_bw20_Left1Right1.gph, replace

* Local macros for panel subtitles	
local Left0Right0 "i) Municipalities with no left- or rightwing representative"
local Left1Right0 "ii) Municipalities with leftwing representative(s) only"
local Left0Right1 "iii) Municipalities with rightwing representative(s) only"
local Left1Right1 "iv) Municipalities with representatives from both blocs"
	
cd gph

foreach combo in Left0Right0 Left1Right0 Left0Right1 Left1Right1 {
graph combine rdplot_sumCAP_full_`combo'.gph rdplot_sumCAP_bw20_`combo'.gph, subtitle("``combo''", size(*1)) ycommon graphregion(color(white)) cols(2) xsize(7) ysize(2)
graph save rdplot_sumCAP_combined_`combo'.gph, replace
}
		
graph combine rdplot_sumCAP_combined_Left0Right0.gph rdplot_sumCAP_combined_Left1Right0.gph rdplot_sumCAP_combined_Left0Right1.gph rdplot_sumCAP_combined_Left1Right1.gph, rows(4) graphregion(color(white)) ysize(7) iscale(*0.9)
graph export ..\Figures\Fig_2.pdf, replace

cd ..


*******************************************************************************
******* REGRESSION TABLES AND FIGURES, CHAPTER 4/CHAPTER 5.2/APPENDIX *********
*******************************************************************************

*** MUST RUN THIS PART BEFORE SYNTAX FOR FIGURES AND TABLES: ***

use dta\panel_mun_elperiod.dta, clear

gen drepRight=max(drepRight1,drepRight2,drepRight3)

renpfix drep

/* Instruments */
foreach party in Left Right1 Right2 Right3{
gen MajLeftX`party'=MajLeft*`party'
}

/* Control function */
forval i=1/3 {
gen dist`i'=dist_coal_margin^`i'
gen dist`i'XMajLeft=dist_coal_margin^`i'*MajLeft
}

/* Interactions */

foreach party in Left Right1 Right2 Right3 {
gen dist1X`party'=dist1*`party'
gen dist1XMajLeftX`party'=dist1*MajLeft*`party'

gen dist2X`party'=dist2*`party'
gen dist2XMajLeftX`party'=dist2*MajLeft*`party'

gen dist3X`party'=dist3*`party'
gen dist3XMajLeftX`party'=dist3*MajLeft*`party'
}

/* Dummy outcome variables */
gen dsum1000=sumCAP>=1000 if sumCAP!=.
gen dsum100=sumCAP>=100 if sumCAP!=.

/* Split by population size */
egen medianpop1995=median(pop1995) if ele==7
egen medianpop=mean(medianpop1995), by(knr)

/* Outcome variables split by population and number of incumbents */
foreach depvar in sumCAP dsum1000 {
gen `depvar'small=`depvar' if pop1995<medianpop
gen `depvar'large=`depvar' if pop1995>=medianpop & pop1995!=.
gen `depvar'noincumb=`depvar' if electionperiod>2&electionperiod<10&reptotal>0&reelected==0
gen `depvar'incumb=`depvar' if electionperiod>2&electionperiod<10&reptotal>0&reelected==reptotal
}

/* Election period fixed effects */
tab election, gen(d_ele)

lab var MajLeft "Left Majority"
foreach party in Left Right1 Right2 Right3 {
lab var MajLeftX`party' "Left Majority $\times$ Rep from `party'"
lab var `party' "Rep. from `party'"
}
lab var Align "Aligned representative"

xtset knr election


*******************************************************************************


*** TABLE 2: FIRST STAGE OF FUZZY RDD, ALL SPECIFICATIONS ***

eststo clear
qui reg Aligned MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3 MajLeft Left Right1 Right2 Right3 dist1* dist2* d_ele*, vce(cluster cnr)
eststo
estadd local MunFE "No"
estadd local TimeFE "Yes"
estadd local PolyDegree "2"
estadd ysumm
test MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3
estadd r(F), replace
qui xtreg Aligned MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3 MajLeft Left Right1 Right2 Right3 dist1* dist2* d_ele*, fe vce(cluster cnr)
eststo
estadd local MunFE "Yes"
estadd local TimeFE "Yes"
estadd local PolyDegree "2"
estadd ysumm
test MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3
estadd r(F), replace
qui reg Aligned MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3 MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele* , vce(cluster cnr)
eststo
estadd local MunFE "No"
estadd local TimeFE "Yes"
estadd local PolyDegree "3"
estadd ysumm
test MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3
estadd r(F), replace
qui xtreg Aligned MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3 MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, fe vce(cluster cnr)
eststo
estadd local MunFE "Yes"
estadd local TimeFE "Yes"
estadd local PolyDegree "3"
estadd ysumm
test MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3
estadd r(F), replace
esttab using Tables\Tab_3.tex, replace style(tex) se b(%9.2f) se(%9.2f) star(* 0.10 ** 0.05 *** 0.01) drop(_cons *d_ele* *dist*) nomtitles label ///
stats(F N ymean MunFE TimeFE PolyDegree, labels ("F-stat., excluded instr." "Observations" "Mean of outcome var." "Municipality fixed effects" "Time fixed effects" "Polynomial order") fmt(2 0 2)) nonotes prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}")  


*******************************************************************************


*** TABLE 3: SECOND STAGE, FUNDING PER CAPITA, ALL SPECIFICATIONS ***

/* Run separate do-files to get p-values:
wildboot NOFE.do
wildboot poly2FE.do
wildboot poly3FE.do 
wildboot OLS.do*/

eststo clear
eststo: qui ivregress 2sls sumCAP (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* d_ele*, vce(cluster cnr) 
estadd local MunFE "No"
estadd local TimeFE "Yes"
estadd local GovFE "No"
estadd local PolyDegree "2"
estadd local WildBoot 0.02
estadd ysumm
eststo: qui xtivreg sumCAP (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* d_ele*, fe vce(cluster cnr) 
estadd local MunFE "Yes"
estadd local TimeFE "Yes"
estadd local GovFE "No"
estadd local PolyDegree "2"
estadd local WildBoot 0.05
estadd ysumm
eststo: qui ivregress 2sls sumCAP (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, vce(cluster cnr) 
estadd local MunFE "No"
estadd local TimeFE "Yes"
estadd local GovFE "No"
estadd local PolyDegree "3"
estadd local WildBoot 0.07
estadd ysumm
eststo: qui xtivreg sumCAP (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, fe vce(cluster cnr) 
estadd local MunFE "Yes"
estadd local TimeFE "Yes"
estadd local GovFE "No"
estadd local PolyDegree "3"
estadd local WildBoot 0.12
estadd ysumm
eststo: qui xtreg sumCAP Aligned GovRight1 GovRight2 GovRight3 Left Right1 Right2 Right3 d_ele*, fe vce(cluster cnr)
estadd local MunFE "Yes"
estadd local TimeFE "Yes"
estadd local GovFE "Yes"
estadd local PolyDegree "-"
estadd local WildBoot 0.09
estadd ysumm
esttab using Tables\Tab_4.tex, replace style(tex) se b(%9.2f) se(%9.2f) star(* 0.10 ** 0.05 *** 0.01) drop(_cons *dist* *d_ele* *Gov*) mtitles("2SLS" "2SLS" "2SLS" "2SLS" "OLS") label ///
nonotes stats(WildBoot N ymean MunFE TimeFE GovFE PolyDegree, labels ("$ p$-value (Aligned rep.)" "Observations" "Mean of outcome var." "Municipality fixed effects" "Time fixed effects" "Governor party dummies" "Polynomial order") fmt(2 0 2)) prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}")  


*******************************************************************************


*** FIGURE 3: FALSIFICATION TEST FOR FUNDING AT TIME t-2, t-1, t, t+1 AND t+2 ***

postfile dataset str10 (spec depvar) lag pointest lower upper using temp\placebos.dta, replace

foreach depvar in sumCAP dsum1000 {

forval lag=0/4 {
qui ivregress 2sls f`lag'.l2.`depvar' (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, vce(cluster cnr)
post dataset ("3 NOFE") ("`depvar'") (`lag'-2) (_b[Aligned]) (_b[Aligned]-1.96*_se[Aligned]) (_b[Aligned]+1.96*_se[Aligned])
}
}
postclose dataset

preserve
use temp\placebos.dta, clear

label var lag "Number of election period leads/lags"

cd gph

twoway (rbar lower upper lag, lwidth(vvthin) lpattern(solid) barwidth(.01)) (scatter pointest lag, msize(medium)) if spec=="3 NOFE"&depvar=="sumCAP", ///
yscale(range(-1500 1500)) yline(0, lwidth(medium) lpattern(dash) lcolor(black)) ///
legend(off) title(Refunds per capita)  graphregion(fcolor(white) ) scheme(s1mono)
graph save illustration_placebo.gph, replace

twoway (rbar lower upper lag, lwidth(vvthin) lpattern(solid) barwidth(.01)) (scatter pointest lag, msize(medium)) if spec=="3 NOFE"&depvar=="dsum1000", ///
yscale(range(-0.4 0.4)) yline(0, lwidth(medium) lpattern(dash) lcolor(black)) ///
legend(off) title(Refunds > 1000 NOK per capita)  graphregion(fcolor(white) ) scheme(s1mono)
graph save illustration_placebo_d1000.gph, replace

graph combine illustration_placebo.gph illustration_placebo_d1000.gph, graphregion(fcolor(white) ) scheme(s1mono) rows(2) iscale(0.6)
graph export ..\Figures\Fig_3.pdf, replace


cd ..
restore


*******************************************************************************


*** TABLE 6: SPLIT ON INCUMBENTS AND POPULATION SIZE ***

/* Run separate do-files to get p-values:
wildboot NOFE.do
wildboot poly3FE.do */

eststo clear
eststo: qui ivregress 2sls sumCAPnoincumb (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, vce(cluster cnr) 
estadd local MunFE "No"
estadd local TimeFE "Yes"
estadd local WildBoot 0.10
estadd local PolyDegree "3"
estadd ysumm
eststo: qui ivregress 2sls dsum1000noincumb (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, vce(cluster cnr) 
estadd local MunFE "No"
estadd local TimeFE "Yes"
estadd local WildBoot 0.08
estadd local PolyDegree "3"
estadd ysumm
eststo: qui ivregress 2sls sumCAPincumb (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, vce(cluster cnr) 
estadd local MunFE "No"
estadd local TimeFE "Yes"
estadd local WildBoot 0.86
estadd local PolyDegree "3"
estadd ysumm
eststo: qui ivregress 2sls dsum1000incumb (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, vce(cluster cnr) 
estadd local MunFE "No"
estadd local TimeFE "Yes"
estadd local WildBoot 0.36
estadd local PolyDegree "3"
estadd ysumm
eststo: qui xtivreg sumCAPsmall (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, fe vce(cluster cnr) 
estadd local MunFE "Yes"
estadd local TimeFE "Yes"
estadd local WildBoot 0.11
estadd local PolyDegree "3"
estadd ysumm
eststo: qui xtivreg dsum1000small (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, fe vce(cluster cnr) 
estadd local MunFE "Yes"
estadd local TimeFE "Yes"
estadd local WildBoot 0.01
estadd local PolyDegree "3"
estadd ysumm
eststo: qui xtivreg sumCAPlarge (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, fe vce(cluster cnr) 
estadd local MunFE "Yes"
estadd local TimeFE "Yes"
estadd local WildBoot 0.90
estadd local PolyDegree "3"
estadd ysumm
eststo: qui xtivreg dsum1000large (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, fe vce(cluster cnr) 
estadd local MunFE "Yes"
estadd local TimeFE "Yes"
estadd local WildBoot 0.21
estadd local PolyDegree "3"
estadd ysumm
esttab using Tables\Tab_6.tex, replace style(tex) se b(%9.2f) se(%9.2f) star(* 0.10 ** 0.05 *** 0.01) drop(*dist* *d_ele* _cons) mtitles("Continuous" "Dummy" "Continuous" "Dummy" "Continuous" "Dummy" "Continuous" "Dummy") label ///
nonotes stats(WildBoot N ymean MunFE TimeFE GovFE PolyDegree, labels ("$ p$-value (Aligned rep.)" "Observations" "Mean of outcome var." "Municipality fixed effects" "Time fixed effects" "Polynomial order") fmt(2 0 2)) /// 
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline" "&\multicolumn{2}{c}{No incumbents}&\multicolumn{2}{c}{Only incumbents}&\multicolumn{2}{c}{Small population}&\multicolumn{2}{c}{Large population}\\") posthead(\hline) postfoot("\hline" "\end{tabular}")  


*******************************************************************************


**** ONLINE APPENDIX FIGURES B1-B2: SENSITIVITY TEST FOR VARYING THE BANDWIDTH ***

* 1) Estimate model for all different bandwidths (0.01-0.25) *

postfile dataset polyorder str10 (depvar) double (BW) pointest lower upper using temp\bandwidths.dta, replace

foreach depvar in sumCAP dsum1000 {
forval BW=1/25 {
qui ivregress 2sls `depvar' (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* d_ele* if abs(dist_coal_margin)<=`BW'/100, vce(cluster cnr)
post dataset (2) ("`depvar'") (`BW') (_b[Aligned]) (_b[Aligned]-1.96*_se[Aligned]) (_b[Aligned]+1.96*_se[Aligned])
qui ivregress 2sls `depvar' (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* d_ele* if abs(dist_coal_margin)<=`BW'/100, vce(cluster cnr)
post dataset (1) ("`depvar'") (`BW') (_b[Aligned]) (_b[Aligned]-1.96*_se[Aligned]) (_b[Aligned]+1.96*_se[Aligned])
}
}
postclose dataset

* 2) Then obtain optimal bandwidths from classic RDD shown in Figure 2 *

forval i=1/2 {
foreach depvar in sumCAP dsum1000 {
qui rdrobust `depvar' dist1 if Left==1&Right==0, c(0) p(`i') bwselect(IK)
local BW1_`depvar'_poly`i'=e(h_bw)
qui rdrobust `depvar' dist1 if Left==0&Right==1, c(0) p(`i') bwselect(IK)
local BW2_`depvar'_poly`i'=e(h_bw)
}
}

* 3) Then plot estimates, confidende intervals and optimal bandwidths. (Run jointly with step 2!)*

preserve
use temp\bandwidths.dta, clear

replace BW=BW/100

replace lower=. if BW<0.03
replace upper=. if BW<0.03

lab var BW "Bandwidth"

forval i=1/2 {

twoway (rbar lower upper BW, lwidth(vvthin) lpattern(solid) barwidth(.00025)) (scatter pointest BW, msize(medium)) if polyorder==`i'&depvar=="sumCAP", ///
yline(0, lwidth(thin) lpattern(dash) lcolor(gray*0.25)) ///
yline(1000, lwidth(thin) lpattern(dash) lcolor(gray*0.25)) ///
yline(-1000, lwidth(thin) lpattern(dash) lcolor(gray*0.25)) ///
yscale(range(-1500 1500)) ylabel(-1000(1000)1000) ///
xline(`BW1_sumCAP_poly`i'' `BW2_sumCAP_poly`i'', lwidth(thin) lpattern(dash) lcolor(black)) ///
legend(off) title(Refunds per capita)  graphregion(fcolor(white) ) scheme(s1mono)
graph save gph\BW_sumCAP_poly`i'.gph, replace


twoway (rbar lower upper BW, lwidth(vvthin) lpattern(solid) barwidth(.00025)) (scatter pointest BW, msize(medium)) if polyorder==`i'&depvar=="dsum1000", ///
yline(0, lwidth(thin) lpattern(dash) lcolor(gray*0.25)) ///
yline(-0.4, lwidth(thin) lpattern(dash) lcolor(gray*0.25)) ///
yline(0.4, lwidth(thin) lpattern(dash) lcolor(gray*0.25)) ///
xline(`BW1_dsum1000_poly`i'' `BW2_dsum1000_poly`i'', lwidth(thin) lpattern(dash) lcolor(black)) ///
yscale(range(-0.5 0.5)) ylabel(-0.4(0.2)0.4) ///
legend(off) title(Refunds > 1000 NOK per capita)  graphregion(fcolor(white) ) scheme(s1mono)
graph save gph\BW_dsum1000_poly`i'.gph, replace
}

cd gph
graph combine BW_sumCAP_poly2.gph BW_dsum1000_poly2.gph, graphregion(fcolor(white) ) scheme(s1mono) rows(2)
graph export ..\Figures\Fig_B1.pdf, replace

graph combine BW_sumCAP_poly1.gph BW_dsum1000_poly1.gph, graphregion(fcolor(white) ) scheme(s1mono) rows(2)
graph export ..\Figures\Fig_B2.pdf, replace

cd ..

restore


*******************************************************************************


*** ONLINE APPENDIX FIGURE C.1 - ROAD CONSTRUCTIONS AS DEPENDENT VARIABLE ***

gen droad100=roadmeter>=100 if roadmeter!=.
forval lag=1/8 {
gen l`lag'_droad100=l`lag'_roadmeter>=100 if l`lag'_roadmeter!=.
}
forval lead=1/11 {
gen f`lead'_droad100=f`lead'_roadmeter>=100 if f`lead'_roadmeter!=.
}

postfile dataset str10 (spec depvar) lag pointest lower upper using temp\placebos_roads.dta, replace

foreach depvar in roadmeter droad100 {
forval lag=8(-1)1 {
qui ivregress 2sls l`lag'_`depvar' (Align = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, cluster(knr)
post dataset ("3 NOFE") ("`depvar'") (-`lag') (_b[Align]) (_b[Align]-1.96*_se[Align]) (_b[Align]+1.96*_se[Align])
}
qui ivregress 2sls `depvar' (Align = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, cluster(knr)
post dataset ("3 NOFE") ("`depvar'") (0) (_b[Align]) (_b[Align]-1.96*_se[Align]) (_b[Align]+1.96*_se[Align])

forval lag=1/11 {
qui ivregress 2sls f`lag'_`depvar' (Align = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, cluster(knr)
post dataset ("3 NOFE") ("`depvar'") (`lag') (_b[Align]) (_b[Align]-1.96*_se[Align]) (_b[Align]+1.96*_se[Align])
}
}
postclose dataset

preserve

use temp\placebos_roads.dta, clear

lab var lag "Year relative to treatment"

cd gph

twoway (rbar lower upper lag, lwidth(vvthin) lpattern(solid) barwidth(.01)) (scatter pointest lag, msize(medium)) if spec=="3 NOFE"&depvar=="roadmeter", ///
xlabel(-8(4)8) yscale(range(-75 75)) ylabel(-50 0 50) yline(0, lwidth(medium) lpattern(dash) lcolor(black)) xline(-4.5 3.5 7.4, lwidth(medium) lpattern(dash) lcolor(gray)) xline(-0.5, lwidth(medium) lpattern(dash) lcolor(red)) ///
legend(off) title(Meters of new road constructions)  graphregion(fcolor(white) ) scheme(s1mono)
graph save illustration_placebo_ysmooth_road_april2016.gph, replace

twoway (rbar lower upper lag, lwidth(vvthin) lpattern(solid) barwidth(.01)) (scatter pointest lag, msize(medium)) if spec=="3 NOFE"&depvar=="droad100", ///
xlabel(-8(4)8) yscale(range(-0.25 0.25)) yline(0, lwidth(medium) lpattern(dash) lcolor(black)) xline(-4.5 3.5 7.4, lwidth(medium) lpattern(dash) lcolor(gray)) xline(-0.5, lwidth(medium) lpattern(dash) lcolor(red)) ///
legend(off) title(Road constructions > 100 meters)  graphregion(fcolor(white) ) scheme(s1mono)
graph save illustration_placebo_ysmooth_droad_april2016.gph, replace

graph combine illustration_placebo_ysmooth_road_april2016.gph illustration_placebo_ysmooth_droad_april2016.gph, graphregion(fcolor(white) ) scheme(s1mono) rows(2) iscale(0.6)
graph export ..\Figures\Fig_C1.pdf, replace

cd ..

restore


*******************************************************************************


*** TABLE A.2: ALTERNATIVE DEPENDENT VARIABLES ***

/* Run separate do-files to get p-values:
wildboot NOFE.do
wildboot poly3FE.do */

eststo clear
eststo: qui ivregress 2sls dsum100 (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, vce(cluster cnr) 
estadd local MunFE "No"
estadd local TimeFE "Yes"
estadd local PolyDegree "3"
estadd local WildBoot 0.95
estadd ysumm
eststo: qui xtivreg dsum100 (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, fe vce(cluster cnr) 
estadd local MunFE "Yes"
estadd local TimeFE "Yes"
estadd local WildBoot 0.39
estadd local PolyDegree "3"
estadd ysumm
eststo: qui ivregress 2sls dsum1000 (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, vce(cluster cnr) 
estadd local MunFE "No"
estadd local TimeFE "Yes"
estadd local PolyDegree "3"
estadd local WildBoot 0.10
estadd ysumm
eststo: qui xtivreg dsum1000 (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, fe vce(cluster cnr) 
estadd local MunFE "Yes"
estadd local TimeFE "Yes"
estadd local WildBoot 0.05
estadd local PolyDegree "3"
estadd ysumm
esttab using Tables\Tab_A2.tex, replace style(tex) se b(%9.2f) se(%9.2f) star(* 0.10 ** 0.05 *** 0.01) drop(*dist* *d_ele* _cons) mtitles("100 NOK" "100 NOK" "1000 NOK" "1000 NOK") label ///
nonotes stats(WildBoot N ymean MunFE TimeFE PolyDegree, labels ("$ p$-value (Aligned rep.)" "Observations" "Mean of outcome var." "Municipality fixed effects" "Time fixed effects" "Polynomial order") fmt(2 0 2)) /// 
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}")  


*******************************************************************************


*** TABLE A.3: CONTROLS FOR ALIGNED LOCAL MAYOR ***

/* Run separate do-files to get p-values:
wildboot NOFE controls.do
wildboot poly2FE controls.do
wildboot poly3FE controls.do 
wildboot OLS controls.do*/

lab var LocalAligned "Aligned local mayor"

eststo clear
eststo: qui ivregress 2sls sumCAP (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) LocalAligned MajLeft Left Right1 Right2 Right3 dist1* dist2* d_ele*, vce(cluster cnr) 
estadd local MunFE "No"
estadd local TimeFE "Yes"
estadd local GovFE "No"
estadd local PolyDegree "2"
estadd local WildBoot 0.03
estadd ysumm
eststo: qui xtivreg sumCAP (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) LocalAligned MajLeft Left Right1 Right2 Right3 dist1* dist2* d_ele*, fe vce(cluster cnr) 
estadd local MunFE "Yes"
estadd local TimeFE "Yes"
estadd local GovFE "No"
estadd local PolyDegree "2"
estadd local WildBoot 0.05
estadd ysumm
eststo: qui ivregress 2sls sumCAP (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) LocalAligned MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, vce(cluster cnr) 
estadd local MunFE "No"
estadd local TimeFE "Yes"
estadd local GovFE "No"
estadd local PolyDegree "3"
estadd local WildBoot 0.08
estadd ysumm
eststo: qui xtivreg sumCAP (Aligned = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) LocalAligned MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele*, fe vce(cluster cnr) 
estadd local MunFE "Yes"
estadd local TimeFE "Yes"
estadd local GovFE "No"
estadd local PolyDegree "3"
estadd local WildBoot 0.12
estadd ysumm
eststo: qui xtreg sumCAP Aligned LocalAligned GovRight1 GovRight2 GovRight3 Left Right1 Right2 Right3 d_ele*, fe vce(cluster cnr)
estadd local MunFE "Yes"
estadd local TimeFE "Yes"
estadd local GovFE "Yes"
estadd local PolyDegree "-"
estadd local WildBoot 0.07
estadd ysumm
esttab using Tables\Tab_A3.tex, replace style(tex) se b(%9.2f) se(%9.2f) star(* 0.10 ** 0.05 *** 0.01) drop(_cons *dist* *d_ele* *GovRight*) mtitles("2SLS" "2SLS" "2SLS" "2SLS" "OLS") label ///
nonotes stats(WildBoot N ymean MunFE TimeFE GovFE PolyDegree, labels ("$ p$-value (Aligned rep.)" "Observations" "Mean of outcome var." "Municipality fixed effects" "Time fixed effects" "Governor party dummies" "Polynomial order") fmt(2 0 2)) prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}")  


*******************************************************************************
************* REGRESSION TABLES AND FIGURES, CHAPTER 5.1/APPENDIX *************
*******************************************************************************


*use dta\cleanpanel_election, clear
use dta\panel_mun_elperiod.dta, clear

tab ele, gen(d_ele)

gen lvoteshareOther=1-lvoteshareLeft-lvoteshareRight1-lvoteshareRight2-lvoteshareRight3
gen VoteShareOther=1-VoteShareLeft-VoteShareRight1-VoteShareRight2-VoteShareRight3

/* Converting to vote shares relative to eligible */

foreach party in Left Right1 Right2 Right3 Other {
replace VoteShare`party'=VoteShare`party'*LocalTurnout
replace lvoteshare`party'=lvoteshare`party'*Turnout
}

gen VoteShareAbstain=1-VoteShareLeft-VoteShareRight1-VoteShareRight2-VoteShareRight3-VoteShareOther
gen lvoteshareAbstain=1-lvoteshareLeft-lvoteshareRight1-lvoteshareRight2-lvoteshareRight3-lvoteshareOther

renpfix VoteShare VoteLocal

* Variable labels * 
foreach party in Left Right1 Right2 Right3 {
lab var no1`party' "Local top cand., `party'"
}

egen countypop1995=sum(pop1995), by(cnr ele)
gen popshare=pop1995/countypop1995


*******************************************************************************

*** TABLE 5 - EFFECT ON SUPPORT OF HAVING A LOCAL TOP CANDIDATE, WITH FIXED EFFECTS AND CONTROL ***

gen VoteLocal=.

eststo clear
foreach party in Left Right1 Right2 Right3 Other Abstain {
replace VoteLocal=VoteLocal`party'
qui xtreg lvoteshare`party' no1Left no1Right1 no1Right2 no1Right3 VoteLocal d_ele*, vce(cluster cnr) fe i(knr)
eststo 
estadd local TimeFE "Yes"
estadd local MunFE "Yes"
estadd local Sample "All"
estadd ysumm
}
esttab using Tables\Tab_5.tex, replace scalars("TimeFE Election FE" "MunFE Municipality FE" "Sample Sample") se b(%9.3f) se(%9.3f) r2 star(* 0.10 ** 0.05 *** 0.01) label ///
stats(r2 N ymean MunFE TimeFE Sample, labels ("R-squared" "Observations" "Mean of outcome var." "Municipality fixed effects" "Time fixed effects") fmt(2 0 2)) drop(*cons* *ele*) prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}")  mtitles(Left Right1 Right2 Right3 Other Abstain) 


*******************************************************************************

*** ONLINE APPENDIX FIGURE E.1: SCATTER PER PARTY ***

cd gph

local title_Left "Labor party (Left)"
local title_Right1 "Centre party (Right1)"
local title_Right2 "Christian democrats (Right2)"
local title_Right3 "Conservatives (Right3)"
local title_Other "Other"
local title_Abstain "Abstain"

foreach party in Left Right1 Right2 Right3 Other Abstain {
twoway (scatter lvoteshare`party' VoteLocal`party', msize(small) msymbol(circle_hollow)) (lfit lvoteshare`party' VoteLocal`party', lwidth(thick)), /// xscale(r(0 0.8)) yscale(r(0 0.8)) ///
legend(off) title(`title_`party'', size(*0.9)) ytitle(Regional Election) xtitle(Local Election) scheme(s2mono) graphregion(color(white))
graph save `party'.gph, replace
}

graph combine Left.gph Right1.gph Right2.gph Right3.gph Other.gph Abstain.gph,  scheme(s2mono) ycommon xcommon graphregion(color(white))
cd ..
graph export Figures\Fig_E1.pdf, replace



*******************************************************************************

*** ONLINE APPENDIX FIGURE E.2: RESIDUALS V POP SIZE  ***

cd gph

foreach party in Left Right1 Right2 Right3 {
qui areg lvoteshare`party' VoteLocal`party' d_ele*, vce(cluster cnr) absorb(knr)
predict residuals`party', residuals
scatter residuals`party' popshare if no1`party'==1, title(`title_`party'') scheme(s2mono) msymbol(circle_hollow) xtitle(Pct. of regional population in municipality) ytitle("") graphregion(color(white))
graph save s`party'.gph, replace
}

graph combine sLeft.gph sRight1.gph sRight2.gph sRight3.gph,  scheme(s2mono) ycommon xcommon graphregion(color(white))
cd ..
graph export Figures\Fig_E2.pdf, replace


*******************************************************************************

*** ONLINE APPENDIX TABLE E.1: MUNICIPALITIES WITH BELOW MEDIAN POPULATION SIZE ***

eststo clear
foreach party in Left Right1 Right2 Right3 Other Abstain {
replace VoteLocal=VoteLocal`party'
qui xtreg lvoteshare`party' no1Left no1Right1 no1Right2 no1Right3 VoteLocal d_ele* if popshare<0.026185, vce(cluster cnr) fe i(knr)
eststo 
estadd local TimeFE "Yes"
estadd local MunFE "Yes"
estadd local Sample "Small pop."
estadd ysumm
}
esttab using Tables\Tab_E1.tex, replace scalars("TimeFE Election FE" "MunFE Municipality FE" "Sample Sample") se b(%9.3f) se(%9.3f) r2 star(* 0.10 ** 0.05 *** 0.01) label ///
stats(r2 N ymean MunFE TimeFE, labels ("R-squared" "Observations" "Mean of outcome var." "Municipality fixed effects" "Time fixed effects") fmt(2 0 2)) drop(*cons* *ele*) prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}")  mtitles(Left Right1 Right2 Right3 Other Abstain) 


*******************************************************************************

*** ONLINE APPENDIX TABLE E.2: MUNICIPALITIES WITH ABOVE MEDIAN POPULATION SIZE ***

eststo clear
foreach party in Left Right1 Right2 Right3 Other Abstain {
replace VoteLocal=VoteLocal`party'
qui xtreg lvoteshare`party' no1Left no1Right1 no1Right2 no1Right3 VoteLocal d_ele* if popshare>0.026185, vce(cluster cnr) fe i(knr)
eststo 
estadd local TimeFE "Yes"
estadd local MunFE "Yes"
estadd local Sample "Large pop."
estadd ysumm
}
esttab using Tables\Tab_E2.tex, replace style(tex) scalars("TimeFE Election FE" "MunFE Municipality FE" "Sample Sample")  se b(%9.3f) se(%9.3f) r2 star(* 0.10 ** 0.05 *** 0.01) label ///
stats(r2 N ymean MunFE TimeFE, labels ("R-squared" "Observations" "Mean of outcome var." "Municipality fixed effects" "Time fixed effects") fmt(2 0 2)) drop(*cons* *ele*) prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}")  mtitles(Left Right1 Right2 Right3 Other Abstain) 



*******************************************************************************
***************** FIGURES AND TABLES, CHAPTER 5.2/APPENDIX ********************
*******************************************************************************


use dta\panel_ind_elyear, clear

xtset id year

gen age=year-byear
gen dist=reps-rank
gen local1st=localrank==1 if localcand!=.

*foreach outcome in cand rep localcand localrep local1st natcand natrep {
foreach outcome in rep localrep local1st natcand natrep {
gen f_`outcome'=f4.`outcome'
}
foreach outcome in rep localrep local1st natcand natrep {
gen l_`outcome'=l4.`outcome'
}

drop if year==1999|year==2015
drop if reps==0

foreach party in DNA H SP KRF FRP SV V {
gen `party'=party=="`party'"
}


*******************************************************************************

*** FIGURE 4: RDD-LIKE PLOTS OF OUTCOMES ON ALL LEVELS OF GOVERNMENT ***

cd gph

local title_rep "Elected regionally at t"
local title_local1st "Local top cand. at t"
local title_natcand "Runs nationally at t+2"

local title_f_rep "Elected regionally at t+4"
local title_f_local1st "Local top cand. at t+4"
local title_f_natcand "Runs nationally at t+6"

local title_l_rep "Elected regionally at t-4"
local title_l_local1st "Local top cand. at t-4"
local title_l_natcand "Runs nationally at t-2"

foreach outcome in rep local1st natcand f_rep f_local1st f_natcand l_rep l_local1st l_natcand {
binscatter `outcome' dist if dist<=6&dist>=-6, discrete by(rep) mcolors(gray gray) lcolors(gray gray) xline(-0.5, lpattern(dash) lcolor(black)) ///
linetype(none) xlabel(-6(1)6) ylabel(0(0.2)1) xtitle("") ytitle("") title(`title_`outcome'', size(*0.9) color(black)) legend(off) graphregion(color(white))
graph save rd_`outcome'.gph, replace
}

graph combine rd_l_rep.gph rd_rep.gph rd_f_rep.gph rd_l_local1st.gph rd_local1st.gph rd_f_local1st.gph rd_l_natcand.gph rd_natcand.gph rd_f_natcand.gph, cols(3) ysize(5.5) graphregion(color(white)) iscale(*0.75)
cd ..
graph export Figures\Fig_4.pdf, replace



*******************************************************************************


*** FIGURE F.1: FREQUENCIES ***

twoway (hist dist if dist>=-20&dist<0, bfcolor(gs10) blcolor(gs6) freq width(1) discrete) ///
(hist dist if dist>=0&dist<=19, bfcolor(gs5) blcolor(gs6) freq width(1) discrete), ///
xtitle("") xlabel(-20(5)15) graphregion(fcolor(white)) legend(off) xsize(6.5)
graph export Figures\Fig_F1.pdf, replace


*******************************************************************************


*** FIGURE F.2: BALANCE TESTS OF COVARIATES ***

cd gph

local title_DNA "Labour party candidate"
local title_H "Conservative candidate"
local title_SP "Centre party candidate"
local title_KRF "Christian dem. candidate"
local title_FRP "Progress party candidate"
local title_SV "Socialist party candidate"
local title_V "Liberal party candidate"

foreach covar in DNA H SP KRF FRP SV V {
binscatter `covar' dist if dist<=6&dist>=-6, discrete by(rep) mcolors(gray gray) lcolors(gray gray) xline(-0.5, lpattern(dash) lcolor(black)) ///
linetype(none) xlabel(-6(1)6) ylabel(0(0.1)0.5) xtitle("") ytitle("") title(`title_`covar'', size(*0.9) color(black)) legend(off) graphregion(color(white))
graph save balance_`covar'.gph, replace
}

local title_age "Age of candidate"
local title_woman "Female candidate"

foreach covar in age {
binscatter `covar' dist if dist<=6&dist>=-6, discrete by(rep) mcolors(gray gray) lcolors(gray gray) xline(-0.5, lpattern(dash) lcolor(black)) ///
linetype(none) xlabel(-6(1)6) ylabel(40(5)55) xtitle("") ytitle("") title(`title_`covar'', size(*0.9) color(black)) legend(off) graphregion(color(white))
graph save balance_`covar'.gph, replace
}

foreach covar in woman {
binscatter `covar' dist if dist<=6&dist>=-6, discrete by(rep) mcolors(gray gray) lcolors(gray gray) xline(-0.5, lpattern(dash) lcolor(black)) ///
linetype(none) xlabel(-6(1)6) ylabel(0.3(0.1)0.6) xtitle("") ytitle("") title(`title_`covar'', size(*0.9) color(black)) legend(off) graphregion(color(white))
graph save balance_`covar'.gph, replace
}

graph combine balance_age.gph balance_woman.gph balance_SV.gph balance_DNA.gph balance_SP.gph balance_KRF.gph balance_V.gph balance_H.gph balance_FRP.gph, cols(3) ysize(5.5) graphregion(color(white)) iscale(*0.75)
cd ..
graph export Figures\Fig_F2.pdf, replace



*******************************************************************************


*** TABLE F.1: COMPARE MARGINAL WINNERS AND MARGINAL LOSERS ***

lab var age "Age"
lab var woman "Female"
lab var DNA "Labour party candidate"
lab var H "Conservative candidate"
lab var SP "Centre party candidate"
lab var KRF "Christian dem. candidate"
lab var FRP "Progress party candidate"
lab var SV "Socialist party candidate"
lab var V "Liberal party candidate"
lab var l_local1st "Local top candidate, $ t-4$"
lab var local1st "Local top candidate, $ t$"
lab var f_local1st "Local top candidate, $ t+4$"
lab var l_rep "Regional council member, $ t-4$"
lab var rep "Regional council member, $ t$"
lab var f_rep "Regional council member, $ t+4$"
lab var l_natcand "Parliament candidate, $ t-2$"
lab var natcand "Parliament candidate, $ t+2$"
lab var f_natcand "Parliament candidate, $ t+6$"


ttest age if dist==-1|dist==0, by(dist)
gen pval_age=r(p)

foreach var in woman SV DNA SP KRF V H FRP l_local1st local1st f_local1st l_rep f_rep l_natcand natcand f_natcand {
prtest `var' if dist==-1|dist==0, by(dist)
gen pval_`var'=2*(1-normal(abs(r(z))))
}

eststo clear
eststo: qui estpost sum age woman SV DNA SP KRF V H FRP  l_rep rep f_rep l_local1st local1st f_local1st l_natcand natcand f_natcand if dist==0
eststo: qui estpost sum age woman SV DNA SP KRF V H FRP  l_rep rep f_rep l_local1st local1st f_local1st l_natcand natcand f_natcand if dist==-1
preserve
foreach var in age woman SV DNA SP KRF V H FRP  l_local1st local1st f_local1st l_rep f_rep l_natcand natcand f_natcand {
replace `var'=pval_`var'
}
replace rep=.
eststo: qui estpost sum age woman SV DNA SP KRF V H FRP  l_rep rep f_rep l_local1st local1st f_local1st l_natcand natcand f_natcand
esttab
restore

esttab using Tables\Tab_F1.tex, replace style(tex) cells(mean(fmt(2) label("(means)"))) b(%9.2f) label ///
mlabels("Winners" "Losers" "$ p$-value", notitles nodepvars) nonumbers nonotes prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}")  


*******************************************************************************

*** TABLE F.2: CAREER OUTCOMES FOR INCUMBENT AND NEW ELECTS ***

lab var l_local1st "Local top candidate, $ t-4$"
lab var local1st "Local top candidate, $ t$"
lab var f_local1st "Local top candidate, $ t+4$"
lab var l_localrep "Local council member, $ t-4$"
lab var localrep "Local council member, $ t$"
lab var f_localrep "Local council member, $ t+4$"
lab var l_rep "Regional council member, $ t-4$"
lab var rep "Regional council member, $ t$"
lab var f_rep "Regional council member, $ t+4$"
lab var l_natcand "Parliament candidate, $ t-2$"
lab var natcand "Parliament candidate, $ t+2$"
lab var f_natcand "Parliament candidate, $ t+6$"
lab var l_natrep "Parliament member, $ t-2$"
lab var natrep "Parliament member, $ t+2$"
lab var f_natrep "Parliament member, $ t+6$"

eststo clear
eststo: qui estpost sum  l_rep rep f_rep l_localrep localrep f_localrep l_local1st local1st f_local1st l_natcand natcand f_natcand l_natrep natrep f_natrep if rep==1
eststo: qui estpost sum  l_rep rep f_rep l_localrep localrep f_localrep l_local1st local1st f_local1st l_natcand natcand f_natcand l_natrep natrep f_natrep if rep==1&incumbent==0
eststo: qui estpost sum  l_rep rep f_rep l_localrep localrep f_localrep l_local1st local1st f_local1st l_natcand natcand f_natcand l_natrep natrep f_natrep if rep==1&incumbent==1

esttab using Tables\Tab_F2.tex, replace style(tex) cells(mean(fmt(2) label("(means)"))) b(%9.2f) label ///
mlabels("All" "New elects" "Incumbent", notitles nodepvars) nonumbers nonotes prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}")  




*******************************************************************************
*********************** REMAINING FIGURES, ONLINE APPENDIX ********************
*******************************************************************************


*** APPENDIX TABLE A.1: DESCRIPTIVE STATISTICS, PARTIES ***

use dta\panel_mun_elperiod.dta, clear

gen GovLeft=GovRight1+GovRight2+GovRight3==0

keep knr election *SV* *Left *Right1 *Right2 *V *Right3 *FRP *Various *VariousLeft *VariousRight

reshape long crepshare cvoteshare lvoteshare drep Gov, j(parti) i(knr election) string

collapse cvoteshare lvoteshare drep crepshare Gov, by(parti)

generate PartyNumber = .

replace PartyNumber = 7 in 1
replace PartyNumber = 2 in 2
replace PartyNumber = 3 in 3
replace PartyNumber = 4 in 4
replace PartyNumber = 6 in 5
replace PartyNumber = 1 in 6
replace PartyNumber = 5 in 7
replace PartyNumber = 10 in 8
replace PartyNumber = 8 in 9
replace PartyNumber = 9 in 10

sort PartyNumber
drop if PartyNumber==.

gen partyacr=parti

replace Gov=0 if Gov==.

*replace parti = "Red Electoral Alliance (RV)" in 1
replace parti = "Socialist Left Party (SV)" if partyacr=="SV"
replace parti = "Labor Party (DNA)" if partyacr=="Left"
replace parti = "Liberal Party (V)" if partyacr=="V"
replace parti = "Centre Party (SP)" if partyacr=="Right1"
replace parti = "Christian Democratic Party (KrF)" if partyacr=="Right2"
replace parti = "Conservative Party (H)" if partyacr=="Right3"
replace parti = "Progress Party (FrP)" if partyacr=="FRP"
replace parti = "Various List Other" if partyacr=="Various"
replace parti = "Various Lists Left" if partyacr=="VariousLeft"
replace parti = "Various Lists Right" if partyacr=="VariousRight"

format  cvoteshare lvoteshare drep crepshare Gov %9.3f

listtab parti crepshare Gov drep lvoteshare using Tables\Tab_D1.tex, replace type rstyle(tabular) ///
head("\begin{table}[htbp] \centering \caption{Descriptive Statistics by Party List \label{DescrStatsByParty}} \begin{tabular}{lcccc}" `"\hline &\multicolumn{2}{c}{Region level}&\multicolumn{2}{c}{Local level}\\ \textit{Party List}&\textit{Seatshare}&\textit{Governor}&\textit{Council Rep.}&\textit{Voteshare}\\ \hline"') ///
foot("\hline" "\end{tabular}" "\newline" "\textit{Note: Descriptives based on election data from 1975-2007.}"  "\end{table}")


*******************************************************************************


*** APPENDIX FIGURE A.1: HISTOGRAMS ***

use dta\panel_mun_elperiod.dta, clear

gen drepRight=max(drepRight1,drepRight2,drepRight3)

renpfix drep 
egen cat=group(Right Left)
local cat1 "Left N Right N"
local cat2 "Left Y Right N"
local cat3 "Left N Right Y"
local cat4 "Left Y Right Y"

forval i=1/4 {
preserve
keep if cat==`i'
twoway (hist dist_coal_margin if dist_coal_margin<0, bfcolor(gs10) blcolor(gs6) freq width(0.02) start(-0.24)) (hist dist_coal_margin if dist_coal_margin>0, ///
bfcolor(gs5) blcolor(gs6) freq width(0.02) start(0.0)), title(`cat`i'') xtitle(Distance to left wing seat majority) legend(off) graphregion(fcolor(white)) 
graph save gph\histogram_cat`i'.gph, replace
restore
}

cd gph
graph combine histogram_cat1.gph histogram_cat2.gph histogram_cat3.gph histogram_cat4.gph, ///
ycommon xcommon graphregion(fcolor(white)) 
graph export ..\Figures\Fig_A1.pdf, replace
cd ..\


*******************************************************************************

*** APPENDIX FIGURE A.2-A.3: BALANCE TESTS FOR COVARIATES ***

use dta\panel_mun_elperiod.dta, clear
xtset knr ele

gen lvoteshareRight=lvoteshareRight1+lvoteshareRight2+lvoteshareRight3
gen logpop=ln(pop)
gen year=1968+electionperiod*4-1
gen VoteShareRight=VoteShareRight1+VoteShareRight2+VoteShareRight3

/* Control function */
forval i=1/3 {
gen dist`i'=dist_coal_margin^`i'
gen dist`i'XMajLeft=dist_coal_margin^`i'*MajLeft
}

cd gph

* FULL BANDWIDTH AND CUBIC CONTROL FUNCTION *

/* p-values to be reported in subtitle */
foreach covar in logpop year Seats LocalTurnout Turnout VoteShareRight lvoteshareRight LocalRight {
qui reg `covar' MajLeft dist*, cluster(cnr)
test MajLeft
local p_`covar'=string(round(r(p),0.01))
}

/* RD plots */
rdplot logpop dist_coal_margin, c(0) p(3) numbinl(5) numbinr(15) graph_options(title("Log population (p = `p_logpop')", size(*0.8)) graphregion(fcolor(white)) legend(off) yscale(range(8 9.5)) ylabel(#4, angle(90)) xscale(range(-0.25 0.25)) xlabel(-0.2(0.1)0.2))
graph save rdplot_cov_pop.gph, replace
rdplot year dist_coal_margin, c(0) p(3) numbinl(5) numbinr(15) graph_options(title("Election year (p = `p_year')", size(*0.8)) graphregion(fcolor(white)) legend(off) yscale(range(1976 2008)) ylabel(1975(16)2007, angle(90)) xscale(range(-0.25 0.25)) xlabel(-0.2(0.1)0.2))
graph save rdplot_cov_year.gph, replace
rdplot Seats dist_coal_margin, c(0) p(3) numbinl(5) numbinr(15) graph_options(title("Regional council size (p = `p_Seats')", size(*0.8)) graphregion(fcolor(white)) legend(off) yscale(range(30 90)) ylabel(40(20)80, angle(90)) xscale(range(-0.25 0.25)) xlabel(-0.2(0.1)0.2))
graph save rdplot_cov_csize.gph, replace
rdplot LocalTurnout dist_coal_margin, c(0) p(3) numbinl(5) numbinr(15) graph_options(title("Turnout, local election (p = `p_LocalTurnout')", size(*0.8)) graphregion(fcolor(white)) legend(off) yscale(range(0.5 1)) ylabel(#4, angle(90)) xscale(range(-0.25 0.25)) xlabel(-0.2(0.1)0.2))
graph save rdplot_cov_turnout.gph, replace
rdplot Turnout dist_coal_margin, c(0) p(3) numbinl(5) numbinr(15) graph_options(title("Turnout, regional election (p = `p_Turnout')", size(*0.8)) graphregion(fcolor(white)) legend(off) yscale(range(0.5 1)) ylabel(#4, angle(90)) xscale(range(-0.25 0.25)) xlabel(-0.2(0.1)0.2))
graph save rdplot_cov_regturnout.gph, replace
rdplot VoteShareRight dist_coal_margin, c(0) p(3) numbinl(5) numbinr(15) graph_options(title("Local support, rightwing parties (p = `p_VoteShareRight')", size(*0.8)) graphregion(fcolor(white)) legend(off) yscale(range(0 0.6)) ylabel(#4, angle(90)) xscale(range(-0.25 0.25)) xlabel(-0.2(0.1)0.2))
graph save rdplot_cov_voteRight.gph, replace
rdplot lvoteshareRight dist_coal_margin, c(0) p(3) numbinl(5) numbinr(15) graph_options(title("Regional support, rightwing parties (p = `p_lvoteshareRight')", size(*0.8)) graphregion(fcolor(white)) legend(off) yscale(range(0 0.6)) ylabel(#4, angle(90)) xscale(range(-0.25 0.25)) xlabel(-0.2(0.1)0.2))
graph save rdplot_cov_regvoteRight.gph, replace
rdplot LocalRight dist_coal_margin, c(0) p(3) numbinl(5) numbinr(15) graph_options(title("Local rightwing mayor (p = `p_LocalRight')", size(*0.8)) graphregion(fcolor(white)) legend(off) yscale(range(0 1)) ylabel(#4, angle(90)) xscale(range(-0.25 0.25)) xlabel(-0.2(0.1)0.2))
graph save rdplot_cov_mayorRight.gph, replace

graph combine rdplot_cov_year.gph rdplot_cov_csize.gph rdplot_cov_pop.gph rdplot_cov_mayorRight.gph  rdplot_cov_turnout.gph rdplot_cov_voteRight.gph  rdplot_cov_regturnout.gph rdplot_cov_regvoteRight.gph, cols(2) ysize(7) graphregion(color(white)) iscale(*0.9)

graph export ..\Figures\Fig_A2.pdf, replace


* 10 PERCENTAGE POINT BANDWIDTH AND LINEAR CONTROL FUNCTION *

foreach covar in logpop year Seats LocalTurnout Turnout VoteShareRight lvoteshareRight LocalRight {
reg `covar' MajLeft dist1* if abs(dist_coal_margin)<=0.1, cluster(cnr)
test MajLeft
local p_`covar'=string(round(r(p),0.01))
}

rdplot logpop dist_coal_margin if abs(dist_coal_margin)<=0.1, c(0) p(1) numbinl(8) numbinr(12) graph_options(title("Log population (p = `p_logpop')", size(*0.8)) graphregion(fcolor(white)) legend(off) yscale(range(8 9.5)) ylabel(#4, angle(90)) xscale(range(-0.1 0.1)) xlabel(-0.1(0.05)0.1))
graph save rdplot_bw10_cov_pop.gph, replace
rdplot year dist_coal_margin if abs(dist_coal_margin)<=0.1, c(0) p(1) numbinl(8) numbinr(12) graph_options(title("Election year (p = `p_year')", size(*0.8)) graphregion(fcolor(white)) legend(off) yscale(range(1976 2008)) ylabel(1975(16)2007, angle(90)) xscale(range(-0.1 0.1)) xlabel(-0.1(0.05)0.1))
graph save rdplot_bw10_cov_year.gph, replace
rdplot Seats dist_coal_margin if abs(dist_coal_margin)<=0.1, c(0) p(1) numbinl(8) numbinr(12) graph_options(title("Regional council size (p = `p_Seats')", size(*0.8)) graphregion(fcolor(white)) legend(off) yscale(range(30 90)) ylabel(40(20)80, angle(90)) xscale(range(-0.1 0.1)) xlabel(-0.1(0.05)0.1))
graph save rdplot_bw10_cov_csize.gph, replace
rdplot LocalTurnout dist_coal_margin if abs(dist_coal_margin)<=0.1, c(0) p(1) numbinl(8) numbinr(12) graph_options(title("Turnout, local election (p = `p_LocalTurnout')", size(*0.8)) graphregion(fcolor(white)) legend(off) yscale(range(0.5 1)) ylabel(#4, angle(90)) xscale(range(-0.1 0.1)) xlabel(-0.1(0.05)0.1))
graph save rdplot_bw10_cov_turnout.gph, replace
rdplot Turnout dist_coal_margin if abs(dist_coal_margin)<=0.1, c(0) p(1) numbinl(8) numbinr(12) graph_options(title("Turnout, regional election (p = `p_Turnout')", size(*0.8)) graphregion(fcolor(white)) legend(off) yscale(range(0.5 1)) ylabel(#4, angle(90)) xscale(range(-0.1 0.1)) xlabel(-0.1(0.05)0.1))
graph save rdplot_bw10_cov_regturnout.gph, replace
rdplot VoteShareRight dist_coal_margin if abs(dist_coal_margin)<=0.1, c(0) p(1) numbinl(8) numbinr(12) graph_options(title("Local support, rightwing parties (p = `p_VoteShareRight')", size(*0.8)) graphregion(fcolor(white)) legend(off) yscale(range(0 0.6)) ylabel(#4, angle(90)) xscale(range(-0.1 0.1)) xlabel(-0.1(0.05)0.1))
graph save rdplot_bw10_cov_voteRight.gph, replace
rdplot lvoteshareRight dist_coal_margin if abs(dist_coal_margin)<=0.1, c(0) p(1) numbinl(8) numbinr(12) graph_options(title("Regional support, rightwing parties (p = `p_lvoteshareRight')", size(*0.8)) graphregion(fcolor(white)) legend(off) yscale(range(0 0.6)) ylabel(#4, angle(90)) xscale(range(-0.1 0.1)) xlabel(-0.1(0.05)0.1))
graph save rdplot_bw10_cov_regvoteRight.gph, replace
rdplot LocalRight dist_coal_margin if abs(dist_coal_margin)<=0.1, c(0) p(1) numbinl(8) numbinr(12) graph_options(title("Local rightwing mayor (p = `p_LocalRight')", size(*0.8)) graphregion(fcolor(white)) legend(off) yscale(range(0 1)) ylabel(#4, angle(90)) xscale(range(-0.1 0.1)) xlabel(-0.1(0.05)0.1))
graph save rdplot_bw10_cov_mayorRight.gph, replace

graph combine rdplot_bw10_cov_year.gph rdplot_bw10_cov_csize.gph rdplot_bw10_cov_pop.gph rdplot_bw10_cov_mayorRight.gph  rdplot_bw10_cov_turnout.gph rdplot_bw10_cov_voteRight.gph  rdplot_bw10_cov_regturnout.gph rdplot_bw10_cov_regvoteRight.gph, cols(2) ysize(7) graphregion(color(white)) iscale(*0.9)

graph export ..\Figures\Fig_A3.pdf, replace

cd ..

*******************************************************************************


*** APPENDIX FIGURE A.4: RD PLOT FOR GOVERNOR'S PARTY ***

use dta\panel_mun_elperiod.dta, clear

local Left "Labor party (Left)"
local Right1 "Center party (Right1)"
local Right2 "Christian democrats (Right2)"
local Right3 "Conservatives (Right3)"

gen GovLeft=1-max(GovRight1,GovRight2,GovRight3)

* Setting scale to get approximately 20 bins in each plot *
cd gph
foreach party in Left Right1 Right2 Right3 {
rdplot Gov`party' dist_coal_margin, c(0) p(3) binselect(qsmv) scalel(5) scaler(0.011) graph_options(graphregion(fcolor(white)) title("``party''", position(12)) legend(off) yscale(range(0 1)) ylabel(#5, angle(0)) xscale(range(-0.25 0.25)) xlabel(-0.2(0.1)0.2)))
graph save Governor`party'_full.gph, replace
}
graph combine GovernorLeft_full.gph GovernorRight1_full.gph GovernorRight2_full.gph GovernorRight3_full.gph, xcommon ycommon graphregion(fcolor(white))
graph export ..\Figures\Fig_A4.pdf, replace

cd ..


*******************************************************************************


*** FIGURE D.1:  ANALYSIS ON YEARLY DATA ***

use dta\panel_mun_year, clear

renpfix drep

gen yelection=year-electionperiod*4-1967

/* Instruments */
foreach party in Left Right1 Right2 Right3{
gen MajLeftX`party'=MajLeft*`party'
}

/* Control function */
forval i=1/3 {
gen dist`i'=dist_coal_margin^`i'
gen dist`i'XMajLeft=dist_coal_margin^`i'*MajLeft
}

/* Interactions */

foreach party in Left Right1 Right2 Right3 {
gen dist1X`party'=dist1*`party'
gen dist1XMajLeftX`party'=dist1*MajLeft*`party'

gen dist2X`party'=dist2*`party'
gen dist2XMajLeftX`party'=dist2*MajLeft*`party'

gen dist3X`party'=dist3*`party'
gen dist3XMajLeftX`party'=dist3*MajLeft*`party'
}

/* Election period fixed effects */
tab election, gen(d_ele)


xtset knr year

postfile dataset str10 (spec depvar) lag pointest lower upper using temp\placebos_yearly.dta, replace

foreach depvar in sumCAP {
forval lag=8(-1)1 {
qui ivregress 2sls l`lag'.`depvar' (Align = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele* if yelection==1, cluster(knr)
post dataset ("3 NOFE") ("`depvar'") (-`lag') (_b[Align]) (_b[Align]-1.96*_se[Align]) (_b[Align]+1.96*_se[Align])
}
qui ivregress 2sls `depvar' (Align = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele* if yelection==1, cluster(knr)
post dataset ("3 NOFE") ("`depvar'") (0) (_b[Align]) (_b[Align]-1.96*_se[Align]) (_b[Align]+1.96*_se[Align])
forval lag=1/8 {

qui ivregress 2sls f`lag'.`depvar' (Align = MajLeftXLeft MajLeftXRight1 MajLeftXRight2 MajLeftXRight3) MajLeft Left Right1 Right2 Right3 dist1* dist2* dist3* d_ele* if yelection==1, cluster(knr)
post dataset ("3 NOFE") ("`depvar'") (`lag') (_b[Align]) (_b[Align]-1.96*_se[Align]) (_b[Align]+1.96*_se[Align])
}
}
postclose dataset


preserve

use temp\placebos_yearly.dta, clear

lab var lag "Year relative to treatment"

drop if lag==8

twoway (rbar lower upper lag, lwidth(vvthin) lpattern(solid) barwidth(.01)) (scatter pointest lag, msize(medium)) if spec=="3 NOFE"&depvar=="sumCAP", ///
xlabel(-8(4)4) yscale(range(-500 500)) xline(-0.5, lwidth(medium) lpattern(dash) lcolor(red)) ///
xline(-4.5, lwidth(medium) lpattern(dash) lcolor(gs9)) xline(3.5, lwidth(medium) lpattern(dash) lcolor(gs9)) ///
yline(0, lwidth(medium) lpattern(dash) lcolor(black)) ///
legend(off) title("Funding per capita")  graphregion(fcolor(white) ) scheme(s1mono) ysize(3)
graph export Figures\Fig_D1.pdf, replace

restore

